import os
import shutil
import bz2

def unpack_files(output_file, destination_folder):
    # Check if the destination folder exists, if not create it
    if not os.path.exists(destination_folder):
        os.makedirs(destination_folder)

    with open(output_file, 'r') as f:
        lines = f.readlines()
        for line in lines:
            line = line.strip()
            if line.endswith(".bz2"):
                # Open the bz2 file and decompress it
                with bz2.BZ2File(line, "rb") as bz2_file:
                    file_name = line.split(".bz2")[0]
                    # Write the decompressed data to a new file
                    with open(file_name, 'wb') as new_file:
                        new_file.write(bz2_file.read())
                    # Copy the new file to the destination folder
                    shutil.copy2(file_name, os.path.join(destination_folder, file_name))
                    # Delete the original file
                    os.remove(file_name)
                    # Change the owner of the file
                    os.chown(os.path.join(destination_folder, file_name), -1, os.getgid())
                    # Change the file permissions
                    os.chmod(os.path.join(destination_folder, file_name), 0o775)
                    print(f"File {file_name} unpacked, owner changed to 'orizon_surf' and permission changed to 775.")

# Test the function
unpack_files("output_modified.txt", "/home/orizon_surf/serverfiles/csgo/maps/test/")
